@@ -208,7 +208,7 @@ static void ReadTuningMapImpl(std::istream& iStrm, CSoundFile& csf, mpt::Charset
 			CTuning *localTuning = TrackerSettings::Instance().oldLocalTunings->GetTuning(str);
 			if(localTuning)
 			{
-				std::unique_ptr<CTuning> pNewTuning = std::unique_ptr<CTuning>(new CTuning(*localTuning));
+				std::unique_ptr<CTuning> pNewTuning = std::make_unique<CTuning>(*localTuning);
 				CTuning *pT = csf.GetTuneSpecificTunings().AddTuning(std::move(pNewTuning));
 				if(pT)
 				{
@@ -687,12 +687,6 @@ bool CSoundFile::ReadIT(FileReader &file, ModLoadingFlags loadFlags)
 		m_MidiCfg.Sanitize();
 	}
 
-	// Ignore MIDI data. Fixes some files like denonde.it that were made with old versions of Impulse Tracker (which didn't support Zxx filters) and have Zxx effects in the patterns.
-	if(fileHeader.cwtv < 0x0214)
-	{
-		m_MidiCfg.ClearZxxMacros();
-	}
-
 	bool hasModPlugExtensions = false;
 
 	// Read pattern names: "PNAM"
@@ -1224,9 +1218,10 @@ bool CSoundFile::ReadIT(FileReader &file, ModLoadingFlags loadFlags)
 			{
 				madeWithTracker = U_("ChibiTracker");
 				m_playBehaviour.reset(kITShortSampleRetrig);
+				m_nSamplePreAmp /= 2;
 			} else if(fileHeader.cwtv == 0x0214 && fileHeader.cmwt == 0x0214 && fileHeader.special <= 1 && fileHeader.pwd == 0 && fileHeader.reserved == 0
 				&& (fileHeader.flags & (ITFileHeader::vol0Optimisations | ITFileHeader::instrumentMode | ITFileHeader::useMIDIPitchController | ITFileHeader::reqEmbeddedMIDIConfig | ITFileHeader::extendedFilterRange)) == ITFileHeader::instrumentMode
-				&& m_nSamples > 0 && (Samples[1].filename == "XXXXXXXX.YYY"))
+				&& m_nSamples > 1 && (Samples[1].filename == "XXXXXXXX.YYY"))
 			{
 				madeWithTracker = U_("CheeseTracker");
 			} else if(fileHeader.cwtv == 0 && madeWithTracker.empty())
@@ -1291,6 +1286,26 @@ bool CSoundFile::ReadIT(FileReader &file, ModLoadingFlags loadFlags)
 			// Initial note memory for channel is C-0: Added 2023-03-09, https://github.com/schismtracker/schismtracker/commit/73e9d60676c2b48c8e94e582373e29517105b2b1
 			if(schismDateVersion < SchismVersionFromDate<2023, 03, 9>::date)
 				m_playBehaviour.reset(kITInitialNoteMemory);
+			// DCT note comparison: Added 2023-10-17, https://github.com/schismtracker/schismtracker/commit/31d36dc00013fc5ab0efa20c782af18e8b006e07
+			if(schismDateVersion < SchismVersionFromDate<2023, 10, 17>::date)
+				m_playBehaviour.reset(kITDCTBehaviour);
+			if(schismDateVersion < SchismVersionFromDate<2023, 10, 19>::date)
+			{
+				// Panbrello sample & hold random waveform: Added 2023-10-19, https://github.com/schismtracker/schismtracker/commit/411ec16b190ba1a486d8b0907ad8d74f8fdc2840
+				m_playBehaviour.reset(kITSampleAndHoldPanbrello);
+				// Don't apply any portamento if no previous note is playing: Added 2023-10-19, https://github.com/schismtracker/schismtracker/commit/8ff0a86a715efb50c89770fb9095d4c4089ff187
+				m_playBehaviour.reset(kITPortaNoNote);
+			}
+			if(schismDateVersion < SchismVersionFromDate<2023, 10, 22>::date)
+			{
+				// Note delay delays first-tick behaviour for slides: Added 2023-10-22, https://github.com/schismtracker/schismtracker/commit/b9609e4f827e1b6ce9ebe6573b85e69388ca0ea0
+				m_playBehaviour.reset(kITFirstTickHandling);
+				// https://github.com/schismtracker/schismtracker/commit/a9e5df533ab52c35190fcc1cbfed4f0347b660bb
+				m_playBehaviour.reset(kITMultiSampleInstrumentNumber);
+			}
+			// Panbrello hold: Added 2024-03-09, https://github.com/schismtracker/schismtracker/commit/ebdebaa8c8a735a7bf49df55debded1b7aac3605
+			if(schismDateVersion < SchismVersionFromDate<2024, 03, 9>::date)
+				m_playBehaviour.reset(kITPanbrelloHold);
 			break;
 		case 4:
 			madeWithTracker = MPT_UFORMAT("pyIT {}.{}")((fileHeader.cwtv & 0x0F00) >> 8, mpt::ufmt::hex0<2>(fileHeader.cwtv & 0xFF));
@@ -1305,7 +1320,12 @@ bool CSoundFile::ReadIT(FileReader &file, ModLoadingFlags loadFlags)
 				madeWithTracker = MPT_UFORMAT("ITMCK {}.{}.{}")((fileHeader.cwtv >> 8) & 0x0F, (fileHeader.cwtv >> 4) & 0x0F, fileHeader.cwtv & 0x0F);
 			break;
 		case 0xD:
-			madeWithTracker = U_("spc2it");
+			if(fileHeader.cwtv == 0xDAEB)
+				madeWithTracker = U_("spc2it");
+			else if(fileHeader.cwtv == 0xD1CE)
+				madeWithTracker = U_("itwriter");
+			else
+				madeWithTracker = U_("Unknown");
 			break;
 		}
 	}
@@ -1313,6 +1333,17 @@ bool CSoundFile::ReadIT(FileReader &file, ModLoadingFlags loadFlags)
 	if(anyADPCM)
 		madeWithTracker += U_(" (ADPCM packed)");
 
+	// Ignore MIDI data. Fixes some files like denonde.it that were made with old versions of Impulse Tracker (which didn't support Zxx filters) and have Zxx effects in the patterns.
+	// Example: denonde.it by Mystical
+	// Note: Only checking the cwtv "made with" version is not enough: spx-visionsofthepast.it has the strange combination of cwtv=2.00, cmwt=2.16
+	// Hence to be sure, we check that both values are below 2.14.
+	// Note that all ModPlug Tracker alpha versions do not support filters yet. Earlier alphas identify as cwtv=2.02, cmwt=2.00, but later alpha versions identify as IT 2.14.
+	// Apart from that, there's an unknown XM conversion tool declaring a lower comaptible version, which naturally also does not support filters, so it's okay that it is caught here.
+	if((fileHeader.cwtv < 0x0214 && fileHeader.cmwt < 0x0214) || (m_dwLastSavedWithVersion && m_dwLastSavedWithVersion <= MPT_V("1.00.00.A6")))
+	{
+		m_MidiCfg.ClearZxxMacros();
+	}
+
 	if(GetType() == MOD_TYPE_MPT)
 	{
 		// START - mpt specific:
